@@ -28,11 +28,11 @@
 
 #include <glib.h>
 
-gchar*      xkb_util_get_flag_filename      (const gchar* group_name);
+gchar*      xkb_util_get_flag_filename      (const gchar   *group_name);
 
-gchar*      xkb_util_get_layout_string      (const gchar* group_name,
-                                             const gchar* variant);
-gchar*      xkb_util_normalize_group_name   (const gchar* group_name,
-                                             const gboolean capitalize);
+gchar*      xkb_util_get_layout_string      (const gchar   *group_name,
+                                             const gchar   *variant);
+gchar*      xkb_util_normalize_group_name   (const gchar   *group_name,
+                                             gboolean       capitalize);
 
 #endif
